@@ -2,51 +2,48 @@ test_that("spread produces legal RasterLayer", {
   testInit(c("dqrng", "terra"))
   rastDF <- needTerraAndRaster()
 
-  set.seed(123)
-  # inputs for x
-  a <- terra::rast(terra::ext(0, 20, 0, 20), res = 1)
-  b <- terra::rast(terra::ext(a), res = 1, vals = stats::runif(ncell(a), 0, 1))
-
-  for (ii in seq(NROW(rastDF))) {
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     pkg <- rastDF$read[ii]
-    rastDF <- needTerraAndRaster()
     read <- eval(parse(text = rastDF$read[ii]))
 
+    set.seed(125)
+    a <- terra::rast(terra::ext(0, 20, 0, 20), resolution = 1)
+    b <- terra::rast(terra::ext(a), resolution = 1, vals = stats::runif(ncell(a), 0, 1))
+
     a <- read(a)
     b <- read(b)
 
-    # check it makes a RasterLayer
+    ## check it makes a RasterLayer
     expect_s4_class(spread(a, loci = ncell(a) / 2, stats::runif(1, 0.15, 0.25)), cls)
 
-    #check wide range of spreadProbs
+    ## check wide range of spreadProbs
     for (wwt in 1:20) {
       expect_s4_class(spread(a, loci = ncell(a) / 2, stats::runif(1, 0, 1)), cls)
     }
 
-
-    # Test for NAs in a numeric vector of spreadProb values
+    ## Test for NAs in a numeric vector of spreadProb values
     numNAs <- 50
     sps <- sample(c(rep(NA_real_, numNAs), runif(ncell(a) - numNAs, 0, 0.5)))
-    expect_s4_class(out <- spread(a, loci = ncell(a) / 2, spreadProb = sps), cls)
+    expect_s4_class(spread(a, loci = ncell(a) / 2, spreadProb = sps), cls)
 
-    # check spreadProbs outside of legal returns an "spreadProb is not a probability"
+    ## check spreadProbs outside of legal returns an "spreadProb is not a probability"
     expect_error(spread(a, loci = ncell(a) / 2, 1.1), "spreadProb is not a probability")
     expect_error(spread(a, loci = ncell(a) / 2, -0.1), "spreadProb is not a probability")
 
-    # checks if maxSize is working properly
-    # One process spreading
+    ## checks if maxSize is working properly
+    ## One process spreading
     expect_equal(ncell(a), tabulate(spread(a, spreadProb = 1, id = TRUE)[]))
 
-    # several processes spreading
+    ## several processes spreading
     sizes <- rep_len(50, 3)
     expect_equal(sizes,
                  tabulate(spread(a, loci = c(40, 200, 350), spreadProb = 1,
                                  id = TRUE, maxSize = sizes)[]))
 
-    # Check that with maxSize, the active cells are removed when maxSize is reached
-    b <- terra::rast(terra::ext(0, 20, 0, 20), res = 1)
+    ## Check that with maxSize, the active cells are removed when maxSize is reached
+    b <- terra::rast(terra::ext(0, 20, 0, 20), resolution = 1)
     if (pkg == "raster::raster") {
       a <- read(a)
     }
@@ -76,10 +73,9 @@ test_that("spread produces legal RasterLayer", {
     for (wwn in 2:4) {
       j <- sample(1:1000, 1)
       set.seed(j)
-      # dqrng::dqset.seed(j)
       fires[[wwn]] <- spread(a, loci = as.integer(sample(1:ncell(a), 10)), returnIndices = TRUE,
-                           spreadProb = 0.235, 0, NULL, 1e8, 8, iterations = 2, id = TRUE,
-                           spreadState = fires[[wwn - 1]])
+                             spreadProb = 0.235, 0, NULL, 1e8, 8, iterations = 2, id = TRUE,
+                             spreadState = fires[[wwn - 1]])
       stopped[[wwn]] <- fires[[wwn]][, sum(active), by = id][V1 == 0, id]
 
       # Test that any fire that stopped previously is not rekindled
@@ -87,8 +83,7 @@ test_that("spread produces legal RasterLayer", {
     }
 
     # Test that passing NA to loci returns a correct data.table
-    set.seed(123)
-    # dqrng::dqset.seed(123)
+    set.seed(125)
 
     fires <- spread(a, loci = as.integer(sample(1:ncell(a), 10)), returnIndices = TRUE,
                     0.235, 0, NULL, 1e8, 8, iterations = 2, id = TRUE)
@@ -98,10 +93,17 @@ test_that("spread produces legal RasterLayer", {
     expect_true(all(fires2[, unique(id)] %in% fires[, unique(id)]))
     expect_true(all(fires[, unique(id)] %in% fires2[, unique(id)]))
 
-    expect_true(all(fires2[, length(initialLocus), by = id][, V1] ==
-                      c(1L, 6L, 8L, 15L, 18L, 21L, 1L, 13L, 17L, 2L)))
+    ## TODO: 2024-05-14 R-devel Windows is failing on CRAN win-builder
+    if (getRversion() <= "4.5.0" && tolower(.Platform$OS.type) != "windows") {
+      if (packageVersion("dqrng") < "0.4.0") {
+        expect_true(all(fires2[, length(initialLocus), by = id][, V1] ==
+                          c(15L, 11L, 8L, 5L, 16L, 7L, 2L, 8L, 6L, 17L)))
+      } else {
+        expect_true(all(fires2[, length(initialLocus), by = id][, V1] ==
+                          c(13L, 8L, 3L, 4L, 8L, 4L, 5L, 17L, 6L, 17L)))
+      }
+    }
   }
-
 })
 
 test_that("allowOverlap -- produces exact result", {
@@ -111,16 +113,14 @@ test_that("allowOverlap -- produces exact result", {
   smallExt <- terra::ext(1, N - 1, 1, N - 1)
   smallExtRas <- terra::rast(smallExt)
   lrgExt <- terra::extend(smallExt, 1)
-  a <- terra::rast(lrgExt, res = 1)
-  for (ii in seq(NROW(rastDF))) {
+  a <- terra::rast(lrgExt, resolution = 1)
+
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     pkg <- rastDF$read[ii]
     read <- eval(parse(text = rastDF$read[ii]))
 
-
-  # for (pkg in c("raster::raster", "terra::rast")) {
-    pkg <- rastDF$read[ii]
     if (pkg == "raster::raster") {
       a <- read(a)
       smallExtRas <- read(smallExtRas)
@@ -133,20 +133,18 @@ test_that("allowOverlap -- produces exact result", {
     # ._spread_3 <- ._spread_19 <-._spread_14 <- 1;
     b <- list()
     set.seed(123445)
-    # dqrng::dqset.seed(123445)
     Nreps <- 100
     sams <- sample(1e7, Nreps)
     for (jjj in seq_along(ao)) {
       b[[jjj]] <- list()
       for (j in seq_len(Nreps)) {
         set.seed(sams[j])
-        # dqrng::dqset.seed(sams[j])
         b[[jjj]][[j]] <- spread(a, loci = mp, spreadProb = 0.22, id = TRUE,
-                              allowOverlap = ao[jjj], returnIndices = TRUE)
+                                allowOverlap = ao[jjj], returnIndices = TRUE)
       }
     }
     bs <- lapply(b, function(x) rbindlist(x, idcol = "rep"))
-    expect_true(all.equal(bs[[1]], bs[[2]])) ## TODO: failing
+    expect_true(all.equal(bs[[1]], bs[[2]]))
 
     ##################################################
     b <- list()
@@ -159,7 +157,7 @@ test_that("allowOverlap -- produces exact result", {
       for (j in seq_len(Nreps)) {
         set.seed(sams[j])
         b[[wte]][[j]] <- spread(a, loci = mps, spreadProb = 0.22, id = TRUE,
-                              allowOverlap = ao[wte], returnIndices = TRUE)
+                                allowOverlap = ao[wte], returnIndices = TRUE)
       }
     }
     bs <- lapply(b, function(x) rbindlist(x, idcol = "rep"))
@@ -176,20 +174,21 @@ test_that("allowOverlap -- produces exact result", {
       stk <- terra::rast(ras)
     }
     stk <- terra::crop(stk, smallExtRas)
-    if (pkg == "raster::raster")
+    if (pkg == "raster::raster") {
       o <- raster::calc(stk, function(x) x[2] >= x[1])
-    else
+    } else {
       o <- terra::app(stk, function(x) x[2] >= x[1])
+    }
 
-    expect_true(sum(o[] == 1) > (ncell(stk) - 10)) ## TODO: failing
+    expect_true(sum(o[] == 1) > (ncell(stk) - 10))
   }
 })
 
 test_that("spread stopRule does not work correctly", {
-
   testInit(c("terra"))
   rastDF <- needTerraAndRaster()
-  for (ii in seq(NROW(rastDF))) {
+
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     pkg <- rastDF$read[ii]
@@ -202,8 +201,8 @@ test_that("spread stopRule does not work correctly", {
     maxVal <- 50
 
     ## stopRule examples
-    #  examples with stopRule, which means that the eventual size is driven by the
-    #  values on the raster passed in to the landscape argument
+    ##  examples with stopRule, which means that the eventual size is driven by the
+    ##  values on the raster passed in to the landscape argument
     set.seed(1234)
     startCells <- as.integer(sample(1:ncell(hab), 10))
     stopRule1 <- function(landscape) sum(landscape) > maxVal
@@ -214,7 +213,7 @@ test_that("spread stopRule does not work correctly", {
     foo <- cbind(vals = as.numeric(hab[stopRuleA > 0]), id = as.numeric(stopRuleA[stopRuleA > 0]))
     expect_true(all(tapply(foo[, "vals"], foo[, "id"], sum) > maxVal))
 
-    # using stopRuleBehavior = "excludePixel"
+    ## using stopRuleBehavior = "excludePixel"
     set.seed(1234)
     stopRuleB <- spread(hab, loci = startCells, 1, 0, NULL, maxSize = 1e6, 8, 1e6,
                         id = TRUE, circle = TRUE, stopRule = stopRule1,
@@ -222,14 +221,14 @@ test_that("spread stopRule does not work correctly", {
     foo <- cbind(vals = as.numeric(hab[stopRuleB > 0]), id = as.numeric(stopRuleB[stopRuleB > 0]))
     expect_true(all(tapply(foo[, "vals"], foo[, "id"], sum) <= maxVal))
 
-    # If boolean, then it is exact
+    ## If boolean, then it is exact
     stopRuleB <- spread(hab2, loci = startCells, 1, 0, NULL, maxSize = 1e6, 8, 1e6,
                         id = TRUE, circle = TRUE, stopRule = stopRule1,
                         stopRuleBehavior = "excludePixel")
     foo <- cbind(vals = as.numeric(hab2[stopRuleB]), id = as.numeric(stopRuleB[stopRuleB > 0]))
     expect_true(all(tapply(foo[, "vals"], foo[, "id"], sum) == maxVal))
 
-    # Test vector maxSize and stopRule when they interfere
+    ## Test vector maxSize and stopRule when they interfere
     maxSizes <- sample(maxVal * 2, length(startCells))
     stopRuleB <- spread(hab2, loci = startCells, 1, 0, NULL, maxSize = maxSizes,
                         8, 1e6, id = TRUE, circle = TRUE, stopRule = stopRule1,
@@ -238,7 +237,7 @@ test_that("spread stopRule does not work correctly", {
     foo <- cbind(vals = as.numeric(hab2[stopRuleB > 0]), id = as.numeric(stopRuleB[stopRuleB > 0]))
     expect_true(all(tapply(foo[, "vals"], foo[, "id"], sum) == pmin(maxSizes, maxVal)))
 
-    # Test non integer maxSize and stopRule when they interfere
+    ## Test non integer maxSize and stopRule when they interfere
     maxSizes <- runif(length(startCells), 1, maxVal * 2)
     stopRuleB <- spread(hab2, loci = startCells, 1, 0, NULL, maxSize = maxSizes, 8,
                         1e6, id = TRUE, circle = TRUE, stopRule = stopRule1,
@@ -247,15 +246,12 @@ test_that("spread stopRule does not work correctly", {
     foo <- cbind(vals = as.numeric(hab2[stopRuleB > 0]), id = as.numeric(stopRuleB[stopRuleB > 0]))
     expect_true(all(tapply(foo[, "vals"], foo[, "id"], sum) == pmin(floor(maxSizes), maxVal)))
 
-    ####################################
-    # Test for stopRuleBehavior
-    ####################################
+    ## Test for stopRuleBehavior ------------------------------------------------
     set.seed(53432)
-
     stopRule2 <- function(landscape) sum(landscape) > maxVal
     startCells <- as.integer(sample(1:ncell(hab), 2))
-    set.seed(53432)
 
+    set.seed(53432)
     circs <- spread(hab, spreadProb = 1, circle = TRUE, loci = startCells,
                     id = TRUE, stopRule = stopRule2, stopRuleBehavior = "includeRing")
     cirs <- as.numeric(terra::values(circs))
@@ -263,7 +259,6 @@ test_that("spread stopRule does not work correctly", {
     expect_true(all(vals >= maxVal))
 
     set.seed(53432)
-
     circs2 <- spread(hab, spreadProb = 1, circle = TRUE, loci = startCells,
                      id = TRUE, stopRule = stopRule2, stopRuleBehavior = "excludeRing")
     cirs <- as.numeric(terra::values(circs2))
@@ -271,7 +266,6 @@ test_that("spread stopRule does not work correctly", {
     expect_true(all(vals <= maxVal))
 
     set.seed(53432)
-
     circs3 <- spread(hab, spreadProb = 1, circle = TRUE, loci = startCells,
                      id = TRUE, stopRule = stopRule2, stopRuleBehavior = "includePixel")
     cirs <- as.numeric(terra::values(circs3))
@@ -279,26 +273,22 @@ test_that("spread stopRule does not work correctly", {
     expect_true(all(vals <= (maxVal + reproducible::maxFn(hab))))
 
     set.seed(53432)
-
     circs4 <- spread(hab, spreadProb = 1, circle = TRUE, loci = startCells,
                      id = TRUE, stopRule = stopRule2, stopRuleBehavior = "excludePixel")
     cirs <- as.numeric(terra::values(circs4))
     vals <- tapply(hab[circs4 > 0], cirs[cirs > 0], sum)
     expect_true(all(vals >= (maxVal - reproducible::maxFn(hab))))
 
-    # There should be 1 extra cell
+    ## There should be 1 extra cell
     expect_true(sum(as.numeric(terra::values(circs4)) > 0) + length(startCells) == sum(as.numeric(terra::values(circs3)) > 0))
-    # Order should be includeRing, includePixel, excludePixel, excludeRing
+    ## Order should be includeRing, includePixel, excludePixel, excludeRing
     expect_true(sum(as.numeric(terra::values(circs)) > 0) > sum(as.numeric(terra::values(circs3)) > 0))
     expect_true(sum(as.numeric(terra::values(circs3)) > 0) > sum(as.numeric(terra::values(circs4)) > 0))
     expect_true(sum(as.numeric(terra::values(circs4)) > 0) > sum(as.numeric(terra::values(circs2)) > 0))
 
-    ####################################
-    # Test for circles using maxDist
-    ####################################
+    ## Test for circles using maxDist -------------------------------------------
 
     set.seed(53432)
-
     stopRule2 <- function(landscape) sum(landscape) > maxVal
     startCells <- as.integer(sample(1:ncell(hab), 1))
 
@@ -310,12 +300,11 @@ test_that("spread stopRule does not work correctly", {
     pd <- as.numeric(terra::distance(centre, allCells, lonlat = FALSE))
     expect_true(maxRadius == max(pd))
 
-    # Test for circles using maxDist
+    ## Test for circles using maxDist
     set.seed(543345)
-
     numCircs <- 4
-    set.seed(53432)
 
+    set.seed(53432)
     stopRule2 <- function(landscape) sum(landscape) > maxVal
     startCells <- as.integer(sample(1:ncell(hab), numCircs))
 
@@ -324,7 +313,7 @@ test_that("spread stopRule does not work correctly", {
                     id = TRUE, circleMaxRadius = maxRadius)
     if (interactive()) terra::plot(circs, new = TRUE)
 
-    for (whCirc in 1:numCircs) {
+    for (whCirc in seq(numCircs)) {
       cells <- which(as.numeric(terra::values(circs)) == whCirc)
       centre <- xyFromCell(hab2, startCells)
       allCells <- xyFromCell(hab2, cells)
@@ -334,7 +323,7 @@ test_that("spread stopRule does not work correctly", {
       circEdge[cells[pd == maxRadius]] <- 1
       expect_true(all(circs[cells[pd == maxRadius]] == whCirc))
       if (!is.null(circs[as.vector(adj(hab2, cells[pd == maxRadius], pairs = FALSE))])) {
-        # Test that there are both 0 and whCirc values, i.e,. it is on an edge
+        ## Test that there are both 0 and whCirc values, i.e,. it is on an edge
         expect_true(all(c(0, whCirc) %in%
                           as.numeric(terra::values(circs)[as.vector(adj(hab2, cells[pd == maxRadius], pairs = FALSE))])))
       }
@@ -346,7 +335,7 @@ test_that("spread stopRule does not work correctly", {
       }
     }
 
-    # Test complex functions
+    ## Test complex functions
     initialLoci <- (ncell(hab) - ncol(hab)) / 2 + c(4, -4)
     endSizes <- seq_along(initialLoci) * 200
     stopRule3 <- function(landscape, id, endSizes) sum(landscape) > endSizes[id]
@@ -359,66 +348,68 @@ test_that("spread stopRule does not work correctly", {
     vals <- tapply(hab[twoCirclesDiffSize > 0], cirs[cirs > 0], sum)
     expect_true(all(vals < endSizes))
 
-    # Test allowOverlap
+    ## Test allowOverlap
     initialLoci <- as.integer(sample(1:ncell(hab), 10))
 
-    #expect_error({
     circs <- spread(hab2, spreadProb = 1, circle = TRUE, loci = initialLoci,
                     id = TRUE, circleMaxRadius = maxRadius, allowOverlap = TRUE)
-    #}) ## TODO: fix error when allowOverlap = TRUE
 
-    #expect_error({
     circs <- spread(hab2, spreadProb = 1, loci = initialLoci,
                     maxSize = 10, allowOverlap = TRUE)
-    #}) ## TODO: fix error when allowOverlap = TRUE
 
-    #expect_error({
     circs <- spread(hab2, spreadProb = 1, loci = initialLoci,
                     maxSize = seq_along(initialLoci) * 3, allowOverlap = TRUE)
-    #}) ## TODO: fix error when allowOverlap = TRUE
 
-    # Test allowOverlap and stopRule
+    ## Test allowOverlap and stopRule
     for (iti in 1:6) {
       maxVal <- sample(10:300, 1)
       stopRule2 <- function(landscape, maxVal) sum(landscape) > maxVal
 
-      #expect_error({
       circs <- spread(hab, spreadProb = 1, circle = TRUE, loci = initialLoci,
                       stopRule = stopRule2, maxVal = maxVal, returnIndices = TRUE,
                       id = TRUE, allowOverlap = TRUE, stopRuleBehavior = "includeRing")
-      # }) ## TODO: fix error when allowOverlap = TRUE
 
-      #vals <- tapply(hab[circs$indices], circs$id, sum) ## TODO: fix allowOverlap error
-      #expect_true(all(vals > maxVal)) ## TODO: fix allowOverlap error
+      if (getRversion() >= "4.3.0") {
+        ## TODO: misc error on R 4.2:
+        ## Error in `tapply(hab[circs$indices], circs$id, sum)`: arguments must have same length
+        vals <- tapply(hab[circs$indices], circs$id, sum)
+        expect_true(all(vals > maxVal))
+      }
     }
 
-    #stopRuleBehavior the allowOverlap
+    ## stopRuleBehavior the allowOverlap
     maxVal <- 20
     stopRule2 <- function(landscape, maxVal) sum(landscape) > maxVal
-    #expect_error({
     circs <- spread(hab, spreadProb = 1, circle = TRUE, loci = initialLoci,
                     stopRule = stopRule2, maxVal = maxVal, returnIndices = TRUE,
                     id = TRUE, allowOverlap = TRUE, stopRuleBehavior = "excludePixel")
-    #}) ## TODO: fix error when allowOverlap = TRUE
-    #vals <- tapply(hab[circs$indices], circs$id, sum) ## TODO: fix allowOwerlap error
-    #expect_true(all(vals <= maxVal)) ## TODO: fix allowOverlap error
+    if (getRversion() >= "4.3.0") {
+      ## TODO: misc error on R 4.2:
+      ## Error in `tapply(hab[circs$indices], circs$id, sum)`: arguments must have same length
+      vals <- tapply(hab[circs$indices], circs$id, sum)
+      expect_true(all(vals <= maxVal))
+    }
 
     maxVal <- sample(10:100, 10)
     stopRule2 <- function(landscape, id, maxVal) sum(landscape) > maxVal[id]
-    #expect_error({
     circs <- spread(hab, spreadProb = 1, circle = TRUE, loci = initialLoci,
                     stopRule = stopRule2, id = TRUE, allowOverlap = TRUE,
                     stopRuleBehavior = "excludePixel", maxVal = maxVal,
                     returnIndices = TRUE)
-    #}) ## TODO: fix error when allowOverlap = TRUE
-    #vals <- tapply(hab[circs$indices], circs$id, sum) ## TODO: fix allowOverlap error
-    #expect_true(all(vals <= maxVal)) ## TODO: fix allowOverlap error
-    # Test that maxSize can be a non integer value (i.e, Real)
+    if (getRversion() >= "4.3.0") {
+      ## TODO: misc error on R 4.2:
+      ## Error in `tapply(hab[circs$indices], circs$id, sum)`: arguments must have same length
+      vals <- tapply(hab[circs$indices], circs$id, sum)
+      expect_true(all(vals <= maxVal))
+    }
 
-    # Test arbitrary raster as part of stopRule
-    # Stop if sum of landscape is big or mean of quality is too small
+    ## Test that maxSize can be a non integer value (i.e, Real)
+
+    ## Test arbitrary raster as part of stopRule
+    ## Stop if sum of landscape is big or mean of quality is too small
+    set.seed(4561)
     for (itj in 1:6) {
-      initialLoci <- as.integer(sample(1:ncell(hab), 10))
+      initialLoci <- as.integer(sample(seq(ncell(hab)), 10))
       quality <- read(hab)
       quality[] <- runif(ncell(quality), 0, 1)
       sumLandscapeRule <- 100
@@ -451,19 +442,18 @@ test_that("spread stopRule does not work correctly", {
         terra::plot(ras)
       }
     }
-
   }
 
+  withr::deferred_run()
 })
 
 test_that("asymmetry doesn't work properly", {
-
   testInit(c("terra"))
   rastDF <- needTerraAndRaster()
 
-  aOrig <- terra::rast(terra::ext(0, 100, 0, 100), res = 1)
+  aOrig <- terra::rast(terra::ext(0, 100, 0, 100), resolution = 1)
 
-  for (ii in seq(NROW(rastDF))) {
+  for (ii in seq_len(NROW(rastDF))) {
     read <- eval(parse(text = rastDF$read[ii]))
 
     hab <- read(system.file("extdata", "hab.tif", package = "SpaDES.tools"))
@@ -480,7 +470,7 @@ test_that("asymmetry doesn't work properly", {
     avgAngles <- numeric(n)
     lenAngles <- numeric(n)
 
-    # function to calculate mean angle -- returns in degrees
+    ## function to calculate mean angle -- returns in degrees
     meanAngle <- function(angles) {
       deg2(atan2(mean(sin(rad2(angles))), mean(cos(rad2(angles)))))
     }
@@ -503,7 +493,7 @@ test_that("asymmetry doesn't work properly", {
       assign(newName, ci)
 
       where2 <- function(name, env = parent.frame()) {
-        # simplified from pryr::where
+        ## simplified from pryr::where
         if (exists(name, env, inherits = FALSE)) env else where2(name, parent.env(env))
       }
       env <- where2(newName)
@@ -524,22 +514,22 @@ test_that("asymmetry doesn't work properly", {
     whBig <- which(lenAngles > 50)
     pred <- (1:n)[whBig] * 20
     expect_true(abs(coef(lm(avgAngles[whBig] ~ pred))[[2]] - 1) < 0.1)
-
-
   }
+
+  withr::deferred_run()
 })
 
 test_that("rings and cir", {
-  # Only terra -- # TODO can be changed when somebody has time -- need to do polygons/vect
+  ## TODO: also need tests with polygons/vect
   testInit(c("terra"))
   rastDF <- needTerraAndRaster()
-  for (ii in seq(NROW(rastDF))) {
+
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     pkg <- rastDF$read[ii]
     read <- eval(parse(text = rastDF$read[ii]))
 
-
     hab <- rast(system.file("extdata", "hab.tif", package = "SpaDES.tools"))#
     terra::crs(hab) <- "epsg:23028"
     names(hab) <- "hab"
@@ -557,10 +547,10 @@ test_that("rings and cir", {
 
     expect_true(NROW(cirsEx) < NROW(cirsIncl))
 
-    # With including pixels, then distances are not strictly within the bounds of minRadius
-    #   and maxRadius, because every cell is included if it has a point anywhere within
-    #   the cell, causing cells whose centres are beyond maxRadius or shorter than minRadius
-    #   to be accepted
+    ## With including pixels, then distances are not strictly within the bounds of minRadius
+    ##   and maxRadius, because every cell is included if it has a point anywhere within
+    ##   the cell, causing cells whose centres are beyond maxRadius or shorter than minRadius
+    ##   to be accepted
     b <- cbind(terra::crds(caribou), id = seq_along(caribou))
     a <- as.matrix(cirsIncl)
     colnames(a)[match(c("id", "indices"), colnames(a))] <- c("id", "to")
@@ -568,7 +558,7 @@ test_that("rings and cir", {
     expect_true(radius * 1.49 < max(dists[, "dists"]))
     expect_true( (radius * 1.01) > min(dists[, "dists"]))
 
-    # With excluding pixels, then distances are strictly within the bounds
+    ## With excluding pixels, then distances are strictly within the bounds
     b <- cbind(terra::crds(caribou), id = seq_along(caribou))
     a <- as.matrix(cirsEx)
     colnames(a)[match(c("id", "indices"), colnames(a))] <- c("id", "to")
@@ -597,7 +587,7 @@ test_that("rings and cir", {
                                    includeBehavior = "excludePixels"))
     expect_true(NROW(cirsExSkinny) == 0)
 
-    # Compare rings and cir -- if start in centre of cells, then should be identical
+    ## Compare rings and cir -- if start in centre of cells, then should be identical
     n <- 2
     caribou <- terra::vect(cbind(x = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5,
                                  y = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5))
@@ -607,7 +597,6 @@ test_that("rings and cir", {
     cirs <- data.table(cir(hab, caribou[1, ], maxRadius = radius * 1.5001, minRadius = radius,
                            simplify = TRUE, allowOverlap = TRUE,
                            includeBehavior = "excludePixels", returnDistances = TRUE))
-    #expect_error({
     cirs2 <- rings(hab, loci, minRadius = radius, maxRadius = radius * 1.5001,
                    allowOverlap = TRUE, returnIndices = TRUE, includeBehavior = "includeRing")
     setkey(cirs,  dists, indices)
@@ -641,7 +630,7 @@ test_that("rings and cir", {
       terra::plot(dists2)
       terra::plot(dists3)
     }
-    diffDists12 <- abs(dists1 - dists2) ## TODO: Error in `dists1 - dists2`: non-numeric argument to binary operator
+    diffDists12 <- abs(dists1 - dists2)
     tabs12 <- table(round(as.numeric(terra::values(diffDists12))))
     expect_true(tabs12[names(tabs12) == 0] / ncell(diffDists12) > 0.99)
     if (interactive())
@@ -649,17 +638,19 @@ test_that("rings and cir", {
     diffDists23 <- abs(dists2 - dists3)
     tabs23 <- table(round(as.numeric(terra::values(diffDists23))))
 
-    # This tests that the two approaches are 99% similar
+    ## This tests that the two approaches are 99% similar
     expect_true(tabs23[names(tabs23) == 0] / ncell(diffDists23) > 0.99)
 
     if (interactive()) {
       terra::plot(diffDists23)
     }
   }
+
+  withr::deferred_run()
 })
 
 test_that("distanceFromPoints does not work correctly", {
-  # Only terra -- # TODO can be changed when somebody has time -- need to do polygons/vect
+  ## TODO: also need tests with polygons/vect
   testInit(c("terra"))
 
   hab <- terra::rast(system.file("extdata", "hab.tif", package = "SpaDES.tools"))
@@ -686,12 +677,12 @@ test_that("distanceFromPoints does not work correctly", {
   distsDFEPMaxD <- dists6 <- distanceFromEachPoint(coords, landscape = hab,
                                                    maxDistance = maxDistance)
 
-  # test that maxDistance arg is working
+  ## test that maxDistance arg is working
   expect_true(round(max(distsDFEPMaxD[, "dists"]), 7) == maxDistance)
 
-  # evaluate cumulativeFn
+  ## evaluate cumulativeFn
   n <- 5
-  hab <- terra::rast(terra::ext(0, 10, 0, 10), res = 1)
+  hab <- terra::rast(terra::ext(0, 10, 0, 10), resolution = 1)
   coords <- cbind(x = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5,
                   y = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5)
   dfep20 <- distanceFromEachPoint(coords[, xycolNames, drop = FALSE], landscape = hab)
@@ -701,6 +692,8 @@ test_that("distanceFromPoints does not work correctly", {
   dfep <- distanceFromEachPoint(coords[, xycolNames, drop = FALSE],
                                 landscape = hab, cumulativeFn = `+`)
   expect_true(sum(idw - dfep[, "dists"]) %==% 0)
+
+  withr::deferred_run()
 })
 
 test_that("simple cir does not work correctly", {
@@ -708,9 +701,9 @@ test_that("simple cir does not work correctly", {
   testInit(c("terra"))
   rastDF <- needTerraAndRaster()
 
-  hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), res = 1)
+  hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), resolution = 1)
 
-  for (ii in seq(NROW(rastDF))) {
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     if (type == "raster")
       hab <- raster::raster(hab)
@@ -725,7 +718,7 @@ test_that("simple cir does not work correctly", {
                     y1 = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5)
     expect_error(cir(hab, coords = coords), "coords must have columns named x and y")
 
-    # test id column in coords
+    ## test id column in coords
     n <- 2
     coords <- cbind(x = (stats::runif(n, xmin(hab) + 0.5, xmax(hab) - 0.5)),
                     y = (stats::runif(n, xmin(hab) + 0.5, xmax(hab) - 0.5)),
@@ -735,7 +728,7 @@ test_that("simple cir does not work correctly", {
     expect_true(all(unique(cirs[, "id"]) == c(45, 56)))
     expect_true(all(distanceFromEachPoint(coords, cirs)[, "dists"] %<=% 1))
 
-    # test closest
+    ## test closest
     n <- 1
     coords <- cbind(x = c(5, 6), y = c(5, 5))
     cirsClosestT <- cir(hab, coords = coords, maxRadius = 2, minRadius = 0,
@@ -766,15 +759,16 @@ test_that("simple cir does not work correctly", {
     expect_s4_class(cirs2, rastDF$class[ii])
     expect_true(min(as.numeric(terra::values(cirs2))) == 0)
 
-    hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), res = c(1, 2))
+    hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), resolution = c(1, 2))
     expect_error(cir(hab, maxRadius = 1, includeBehavior = "excludePixels"),
                  "cir function only accepts rasters with identical resolution in x and y dimensions")
 
-    hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), res = 1)
+    hab <- terra::rast(terra::ext(0, 1e1, 0, 1e1), resolution = 1)
     expect_error(cir(hab, maxRadius = 1, includeBehavior = "excludeRings"),
                  "includeBehavior can only be \"includePixels\" or \"excludePixels\"")
   }
 
+  withr::deferred_run()
 })
 
 test_that("wrap does not work correctly", {
@@ -787,10 +781,10 @@ test_that("wrap does not work correctly", {
   # initialize caribou agents
   n <- 10
 
-  # previous points
+  ## previous points
   x1 <- rep(0, n)
   y1 <- rep(0, n)
-  # initial points, outside of range
+  ## initial points, outside of range
   starts <- cbind(x = stats::runif(n, xrange[1] - 10, xrange[1]),
                   y = stats::runif(n, yrange[1] - 10, yrange[1]))
 
@@ -799,7 +793,7 @@ test_that("wrap does not work correctly", {
   expect_error(SpaDES.tools::wrap(starts, bounds = starts),
                "Unable to determine extent of object of type 'matrix'.")
 
-  # using sf
+  ## using sf
   if (requireNamespace("sf", quietly = TRUE)) {
     sf <- sf::st_as_sf(data.frame(starts, x1, y1), coords = xycolNames)
     expect_true(all(coords(SpaDES.tools::wrap(sf, bounds = hab)) == SpaDES.tools::wrap(starts, hab)))
@@ -810,19 +804,21 @@ test_that("wrap does not work correctly", {
     expect_error(SpaDES.tools::wrap(sf, bounds = starts, withHeading = FALSE),
                  "Unable to determine extent of object of type 'matrix'.")
   }
-  # errors
+  ## errors
   starts <- cbind(x = stats::runif(n, xrange[1] - 10, xrange[1]),
                   y = stats::runif(n, yrange[1] - 10, yrange[1]))
   spdf <- terra::vect(data.frame(starts, x1, y1), geom = xycolNames)#
   expect_false(all(abs(terra::ext(spdf)[]) <= 50))
   out <- SpaDES.tools::wrap(spdf, bounds = terra::ext(hab))
   expect_true(all(abs(terra::ext(out)[]) <= 50))
+
+  withr::deferred_run()
 })
 
 test_that("cir angles arg doesn't work", {
   testInit(c("terra", "fpCompare"))
 
-  ras <- terra::rast(terra::ext(0, 100, 0, 100), res = 1)
+  ras <- terra::rast(terra::ext(0, 100, 0, 100), resolution = 1)
   ras[] <- 0
   n <- 2
   set.seed(321)
@@ -834,19 +830,21 @@ test_that("cir angles arg doesn't work", {
   anglesTab <- table(circ[, "angles"])
   expect_true(all(as.numeric(names(anglesTab)) %==% angles))
   expect_true(all(length(anglesTab) == (length(angles))))
+
+  withr::deferred_run()
 })
 
 test_that("multi-core version of distanceFromEachPoints does not work correctly", {
-  # Only raster -- beginCluster is a mechanism only in raster AFAIK (Eliot)
+  ## Only raster -- beginCluster is a mechanism only in raster AFAIK (Eliot)
   skip_on_cran()
   skip_on_ci()
 
   if (interactive()) {
     testInit(c("raster", "parallel", "DEoptim"))
 
-    hab <- randomPolygons(terra::rast(terra::ext(0, 1e2, 0, 1e2)), res = 1)
+    hab <- randomPolygons(terra::rast(terra::ext(0, 1e2, 0, 1e2)), resolution = 1)
 
-    # evaluate cumulativeFn
+    ## evaluate cumulativeFn
     n <- 50
     coords <- cbind(x = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5,
                     y = round(stats::runif(n, xmin(hab), xmax(hab))) + 0.5)
@@ -878,22 +876,22 @@ test_that("multi-core version of distanceFromEachPoints does not work correctly"
     raster::endCluster()
     expect_true(all.equal(dfep, dfepCluster2))
   }
+
+  withr::deferred_run()
 })
 
 test_that("spreadProb with relative values does not work correctly", {
   testInit(c("terra"))
   rastDF <- needTerraAndRaster()
 
-  rastDF <- needTerraAndRaster()
   ext1 <- terra::ext(0, 1e2, 0, 1e2)
-  extRas <- terra::rast(ext1, res = 1)
-  for (ii in seq(NROW(rastDF))) {
+  extRas <- terra::rast(ext1, resolution = 1)
+  for (ii in seq_len(NROW(rastDF))) {
     type <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     pkg <- rastDF$read[ii]
     read <- eval(parse(text = rastDF$read[ii]))
 
-
     seed <- 64350
     set.seed(seed)
     emptyRas <- read(extRas)
